// src/components/TooltipController/TooltipController.tsx
import { useEffect as useEffect4, useState as useState3 } from "react";

// src/components/Tooltip/Tooltip.tsx
import { useEffect as useEffect3, useState as useState2, useRef as useRef2 } from "react";
import classNames2 from "classnames";

// src/utils/debounce.ts
var debounce = (func, wait, immediate) => {
  let timeout = null;
  return function debounced(...args) {
    const later = () => {
      timeout = null;
      if (!immediate) {
        func.apply(this, args);
      }
    };
    if (timeout) {
      clearTimeout(timeout);
    }
    timeout = setTimeout(later, wait);
  };
};
var debounce_default = debounce;

// src/components/TooltipProvider/TooltipProvider.tsx
import {
  createContext,
  useCallback,
  useContext,
  useMemo,
  useState
} from "react";
import { jsx } from "react/jsx-runtime";
var DEFAULT_TOOLTIP_ID = "DEFAULT_TOOLTIP_ID";
var DEFAULT_CONTEXT_DATA = {
  anchorRefs: /* @__PURE__ */ new Set(),
  activeAnchor: { current: null },
  attach: () => {
  },
  detach: () => {
  },
  setActiveAnchor: () => {
  }
};
var DEFAULT_CONTEXT_DATA_WRAPPER = {
  getTooltipData: () => DEFAULT_CONTEXT_DATA
};
var TooltipContext = createContext(DEFAULT_CONTEXT_DATA_WRAPPER);
var TooltipProvider = ({ children }) => {
  const [anchorRefMap, setAnchorRefMap] = useState({
    [DEFAULT_TOOLTIP_ID]: /* @__PURE__ */ new Set()
  });
  const [activeAnchorMap, setActiveAnchorMap] = useState({
    [DEFAULT_TOOLTIP_ID]: { current: null }
  });
  const attach = (tooltipId, ...refs) => {
    setAnchorRefMap((oldMap) => {
      var _a;
      const tooltipRefs = (_a = oldMap[tooltipId]) != null ? _a : /* @__PURE__ */ new Set();
      refs.forEach((ref) => tooltipRefs.add(ref));
      return { ...oldMap, [tooltipId]: new Set(tooltipRefs) };
    });
  };
  const detach = (tooltipId, ...refs) => {
    setAnchorRefMap((oldMap) => {
      const tooltipRefs = oldMap[tooltipId];
      if (!tooltipRefs) {
        return oldMap;
      }
      refs.forEach((ref) => tooltipRefs.delete(ref));
      return { ...oldMap };
    });
  };
  const setActiveAnchor = (tooltipId, ref) => {
    setActiveAnchorMap((oldMap) => {
      var _a;
      if (((_a = oldMap[tooltipId]) == null ? void 0 : _a.current) === ref.current) {
        return oldMap;
      }
      return { ...oldMap, [tooltipId]: ref };
    });
  };
  const getTooltipData = useCallback(
    (tooltipId = DEFAULT_TOOLTIP_ID) => {
      var _a, _b;
      return {
        anchorRefs: (_a = anchorRefMap[tooltipId]) != null ? _a : /* @__PURE__ */ new Set(),
        activeAnchor: (_b = activeAnchorMap[tooltipId]) != null ? _b : { current: null },
        attach: (...refs) => attach(tooltipId, ...refs),
        detach: (...refs) => detach(tooltipId, ...refs),
        setActiveAnchor: (ref) => setActiveAnchor(tooltipId, ref)
      };
    },
    [anchorRefMap, activeAnchorMap, attach, detach]
  );
  const context = useMemo(() => {
    return {
      getTooltipData
    };
  }, [getTooltipData]);
  return /* @__PURE__ */ jsx(TooltipContext.Provider, { value: context, children });
};
function useTooltip(tooltipId = DEFAULT_TOOLTIP_ID) {
  return useContext(TooltipContext).getTooltipData(tooltipId);
}
var TooltipProvider_default = TooltipProvider;

// src/components/TooltipProvider/TooltipWrapper.tsx
import { useEffect, useRef } from "react";
import classNames from "classnames";
import { jsx as jsx2 } from "react/jsx-runtime";
var TooltipWrapper = ({
  tooltipId,
  children,
  className,
  place,
  content,
  html,
  variant,
  offset: offset2,
  wrapper,
  events,
  positionStrategy,
  delayShow,
  delayHide
}) => {
  const { attach, detach } = useTooltip(tooltipId);
  const anchorRef = useRef(null);
  useEffect(() => {
    attach(anchorRef);
    return () => {
      detach(anchorRef);
    };
  }, []);
  return /* @__PURE__ */ jsx2(
    "span",
    {
      ref: anchorRef,
      className: classNames("react-tooltip-wrapper", className),
      "data-tooltip-place": place,
      "data-tooltip-content": content,
      "data-tooltip-html": html,
      "data-tooltip-variant": variant,
      "data-tooltip-offset": offset2,
      "data-tooltip-wrapper": wrapper,
      "data-tooltip-events": events,
      "data-tooltip-position-strategy": positionStrategy,
      "data-tooltip-delay-show": delayShow,
      "data-tooltip-delay-hide": delayHide,
      children
    }
  );
};
var TooltipWrapper_default = TooltipWrapper;

// src/utils/use-isomorphic-layout-effect.ts
import { useLayoutEffect, useEffect as useEffect2 } from "react";
var useIsomorphicLayoutEffect = typeof window !== "undefined" ? useLayoutEffect : useEffect2;
var use_isomorphic_layout_effect_default = useIsomorphicLayoutEffect;

// src/utils/compute-positions.ts
import { computePosition, offset, shift, arrow, flip } from "@floating-ui/dom";
var computeTooltipPosition = async ({
  elementReference = null,
  tooltipReference = null,
  tooltipArrowReference = null,
  place = "top",
  offset: offsetValue = 10,
  strategy = "absolute",
  middlewares = [offset(Number(offsetValue)), flip(), shift({ padding: 5 })]
}) => {
  if (!elementReference) {
    return { tooltipStyles: {}, tooltipArrowStyles: {}, place };
  }
  if (tooltipReference === null) {
    return { tooltipStyles: {}, tooltipArrowStyles: {}, place };
  }
  const middleware = middlewares;
  if (tooltipArrowReference) {
    middleware.push(arrow({ element: tooltipArrowReference, padding: 5 }));
    return computePosition(elementReference, tooltipReference, {
      placement: place,
      strategy,
      middleware
    }).then(({ x, y, placement, middlewareData }) => {
      var _a, _b;
      const styles = { left: `${x}px`, top: `${y}px` };
      const { x: arrowX, y: arrowY } = (_a = middlewareData.arrow) != null ? _a : { x: 0, y: 0 };
      const staticSide = (_b = {
        top: "bottom",
        right: "left",
        bottom: "top",
        left: "right"
      }[placement.split("-")[0]]) != null ? _b : "bottom";
      const arrowStyle = {
        left: arrowX != null ? `${arrowX}px` : "",
        top: arrowY != null ? `${arrowY}px` : "",
        right: "",
        bottom: "",
        [staticSide]: "-4px"
      };
      return { tooltipStyles: styles, tooltipArrowStyles: arrowStyle, place: placement };
    });
  }
  return computePosition(elementReference, tooltipReference, {
    placement: "bottom",
    strategy,
    middleware
  }).then(({ x, y, placement }) => {
    const styles = { left: `${x}px`, top: `${y}px` };
    return { tooltipStyles: styles, tooltipArrowStyles: {}, place: placement };
  });
};

// esbuild-css-modules-plugin-namespace:./src/components/Tooltip/styles.module.css?esbuild-css-modules-plugin-building
var styles_module_default = { "arrow": "react-tooltip__arrow_KtSkBq", "clickable": "react-tooltip__clickable_KtSkBq", "dark": "react-tooltip__dark_KtSkBq", "error": "react-tooltip__error_KtSkBq", "fixed": "react-tooltip__fixed_KtSkBq", "info": "react-tooltip__info_KtSkBq", "light": "react-tooltip__light_KtSkBq", "noArrow": "react-tooltip__no-arrow_KtSkBq", "show": "react-tooltip__show_KtSkBq", "success": "react-tooltip__success_KtSkBq", "tooltip": "react-tooltip__tooltip_KtSkBq", "warning": "react-tooltip__warning_KtSkBq" };

// src/components/Tooltip/Tooltip.tsx
import { jsx as jsx3, jsxs } from "react/jsx-runtime";
var Tooltip = ({
  // props
  id,
  className,
  classNameArrow,
  variant = "dark",
  anchorId,
  anchorSelect,
  place = "top",
  offset: offset2 = 10,
  events = ["hover"],
  openOnClick = false,
  positionStrategy = "absolute",
  middlewares,
  wrapper: WrapperElement,
  delayShow = 0,
  delayHide = 0,
  float = false,
  noArrow = false,
  clickable = false,
  closeOnEsc = false,
  style: externalStyles,
  position,
  afterShow,
  afterHide,
  // props handled by controller
  content,
  isOpen,
  setIsOpen,
  activeAnchor,
  setActiveAnchor
}) => {
  const tooltipRef = useRef2(null);
  const tooltipArrowRef = useRef2(null);
  const tooltipShowDelayTimerRef = useRef2(null);
  const tooltipHideDelayTimerRef = useRef2(null);
  const [actualPlacement, setActualPlacement] = useState2(place);
  const [inlineStyles, setInlineStyles] = useState2({});
  const [inlineArrowStyles, setInlineArrowStyles] = useState2({});
  const [show, setShow] = useState2(false);
  const [rendered, setRendered] = useState2(false);
  const wasShowing = useRef2(false);
  const lastFloatPosition = useRef2(null);
  const { anchorRefs, setActiveAnchor: setProviderActiveAnchor } = useTooltip(id);
  const hoveringTooltip = useRef2(false);
  const [anchorsBySelect, setAnchorsBySelect] = useState2([]);
  const mounted = useRef2(false);
  const shouldOpenOnClick = openOnClick || events.includes("click");
  use_isomorphic_layout_effect_default(() => {
    mounted.current = true;
    return () => {
      mounted.current = false;
    };
  }, []);
  useEffect3(() => {
    if (!show) {
      const timeout = setTimeout(() => {
        setRendered(false);
      }, 150);
      return () => {
        clearTimeout(timeout);
      };
    }
    return () => null;
  }, [show]);
  const handleShow = (value) => {
    if (!mounted.current) {
      return;
    }
    if (value) {
      setRendered(true);
    }
    setTimeout(() => {
      if (!mounted.current) {
        return;
      }
      setIsOpen == null ? void 0 : setIsOpen(value);
      if (isOpen === void 0) {
        setShow(value);
      }
    }, 10);
  };
  useEffect3(() => {
    if (isOpen === void 0) {
      return () => null;
    }
    if (isOpen) {
      setRendered(true);
    }
    const timeout = setTimeout(() => {
      setShow(isOpen);
    }, 10);
    return () => {
      clearTimeout(timeout);
    };
  }, [isOpen]);
  useEffect3(() => {
    if (show === wasShowing.current) {
      return;
    }
    wasShowing.current = show;
    if (show) {
      afterShow == null ? void 0 : afterShow();
    } else {
      afterHide == null ? void 0 : afterHide();
    }
  }, [show]);
  const handleShowTooltipDelayed = () => {
    if (tooltipShowDelayTimerRef.current) {
      clearTimeout(tooltipShowDelayTimerRef.current);
    }
    tooltipShowDelayTimerRef.current = setTimeout(() => {
      handleShow(true);
    }, delayShow);
  };
  const handleHideTooltipDelayed = (delay = delayHide) => {
    if (tooltipHideDelayTimerRef.current) {
      clearTimeout(tooltipHideDelayTimerRef.current);
    }
    tooltipHideDelayTimerRef.current = setTimeout(() => {
      if (hoveringTooltip.current) {
        return;
      }
      handleShow(false);
    }, delay);
  };
  const handleShowTooltip = (event) => {
    var _a;
    if (!event) {
      return;
    }
    if (delayShow) {
      handleShowTooltipDelayed();
    } else {
      handleShow(true);
    }
    const target = (_a = event.currentTarget) != null ? _a : event.target;
    setActiveAnchor(target);
    setProviderActiveAnchor({ current: target });
    if (tooltipHideDelayTimerRef.current) {
      clearTimeout(tooltipHideDelayTimerRef.current);
    }
  };
  const handleHideTooltip = () => {
    if (clickable) {
      handleHideTooltipDelayed(delayHide || 100);
    } else if (delayHide) {
      handleHideTooltipDelayed();
    } else {
      handleShow(false);
    }
    if (tooltipShowDelayTimerRef.current) {
      clearTimeout(tooltipShowDelayTimerRef.current);
    }
  };
  const handleTooltipPosition = ({ x, y }) => {
    const virtualElement = {
      getBoundingClientRect() {
        return {
          x,
          y,
          width: 0,
          height: 0,
          top: y,
          left: x,
          right: x,
          bottom: y
        };
      }
    };
    computeTooltipPosition({
      place,
      offset: offset2,
      elementReference: virtualElement,
      tooltipReference: tooltipRef.current,
      tooltipArrowReference: tooltipArrowRef.current,
      strategy: positionStrategy,
      middlewares
    }).then((computedStylesData) => {
      if (Object.keys(computedStylesData.tooltipStyles).length) {
        setInlineStyles(computedStylesData.tooltipStyles);
      }
      if (Object.keys(computedStylesData.tooltipArrowStyles).length) {
        setInlineArrowStyles(computedStylesData.tooltipArrowStyles);
      }
      setActualPlacement(computedStylesData.place);
    });
  };
  const handleMouseMove = (event) => {
    if (!event) {
      return;
    }
    const mouseEvent = event;
    const mousePosition = {
      x: mouseEvent.clientX,
      y: mouseEvent.clientY
    };
    handleTooltipPosition(mousePosition);
    lastFloatPosition.current = mousePosition;
  };
  const handleClickTooltipAnchor = (event) => {
    handleShowTooltip(event);
    if (delayHide) {
      handleHideTooltipDelayed();
    }
  };
  const handleClickOutsideAnchors = (event) => {
    var _a;
    const anchorById = document.querySelector(`[id='${anchorId}']`);
    const anchors = [anchorById, ...anchorsBySelect];
    if (anchors.some((anchor) => anchor == null ? void 0 : anchor.contains(event.target))) {
      return;
    }
    if ((_a = tooltipRef.current) == null ? void 0 : _a.contains(event.target)) {
      return;
    }
    handleShow(false);
  };
  const handleEsc = (event) => {
    if (event.key !== "Escape") {
      return;
    }
    handleShow(false);
  };
  const debouncedHandleShowTooltip = debounce_default(handleShowTooltip, 50);
  const debouncedHandleHideTooltip = debounce_default(handleHideTooltip, 50);
  useEffect3(() => {
    var _a, _b;
    const elementRefs = new Set(anchorRefs);
    anchorsBySelect.forEach((anchor) => {
      elementRefs.add({ current: anchor });
    });
    const anchorById = document.querySelector(`[id='${anchorId}']`);
    if (anchorById) {
      elementRefs.add({ current: anchorById });
    }
    if (closeOnEsc) {
      window.addEventListener("keydown", handleEsc);
    }
    const enabledEvents = [];
    if (shouldOpenOnClick) {
      window.addEventListener("click", handleClickOutsideAnchors);
      enabledEvents.push({ event: "click", listener: handleClickTooltipAnchor });
    } else {
      enabledEvents.push(
        { event: "mouseenter", listener: debouncedHandleShowTooltip },
        { event: "mouseleave", listener: debouncedHandleHideTooltip },
        { event: "focus", listener: debouncedHandleShowTooltip },
        { event: "blur", listener: debouncedHandleHideTooltip }
      );
      if (float) {
        enabledEvents.push({
          event: "mousemove",
          listener: handleMouseMove
        });
      }
    }
    const handleMouseEnterTooltip = () => {
      hoveringTooltip.current = true;
    };
    const handleMouseLeaveTooltip = () => {
      hoveringTooltip.current = false;
      handleHideTooltip();
    };
    if (clickable && !shouldOpenOnClick) {
      (_a = tooltipRef.current) == null ? void 0 : _a.addEventListener("mouseenter", handleMouseEnterTooltip);
      (_b = tooltipRef.current) == null ? void 0 : _b.addEventListener("mouseleave", handleMouseLeaveTooltip);
    }
    enabledEvents.forEach(({ event, listener }) => {
      elementRefs.forEach((ref) => {
        var _a2;
        (_a2 = ref.current) == null ? void 0 : _a2.addEventListener(event, listener);
      });
    });
    return () => {
      var _a2, _b2;
      if (shouldOpenOnClick) {
        window.removeEventListener("click", handleClickOutsideAnchors);
      }
      if (closeOnEsc) {
        window.removeEventListener("keydown", handleEsc);
      }
      if (clickable && !shouldOpenOnClick) {
        (_a2 = tooltipRef.current) == null ? void 0 : _a2.removeEventListener("mouseenter", handleMouseEnterTooltip);
        (_b2 = tooltipRef.current) == null ? void 0 : _b2.removeEventListener("mouseleave", handleMouseLeaveTooltip);
      }
      enabledEvents.forEach(({ event, listener }) => {
        elementRefs.forEach((ref) => {
          var _a3;
          (_a3 = ref.current) == null ? void 0 : _a3.removeEventListener(event, listener);
        });
      });
    };
  }, [rendered, anchorRefs, anchorsBySelect, closeOnEsc, events]);
  useEffect3(() => {
    let selector = anchorSelect != null ? anchorSelect : "";
    if (!selector && id) {
      selector = `[data-tooltip-id='${id}']`;
    }
    const documentObserverCallback = (mutationList) => {
      const newAnchors = [];
      mutationList.forEach((mutation) => {
        if (mutation.type === "attributes" && mutation.attributeName === "data-tooltip-id") {
          const newId = mutation.target.getAttribute("data-tooltip-id");
          if (newId === id) {
            newAnchors.push(mutation.target);
          }
        }
        if (mutation.type !== "childList") {
          return;
        }
        if (activeAnchor) {
          ;
          [...mutation.removedNodes].some((node) => {
            var _a;
            if ((_a = node == null ? void 0 : node.contains) == null ? void 0 : _a.call(node, activeAnchor)) {
              setRendered(false);
              handleShow(false);
              setActiveAnchor(null);
              return true;
            }
            return false;
          });
        }
        if (!selector) {
          return;
        }
        try {
          const elements = [...mutation.addedNodes].filter((node) => node.nodeType === 1);
          newAnchors.push(
            ...elements.filter(
              (element) => element.matches(selector)
            )
          );
          newAnchors.push(
            ...elements.flatMap(
              (element) => [...element.querySelectorAll(selector)]
            )
          );
        } catch (e) {
        }
      });
      if (newAnchors.length) {
        setAnchorsBySelect((anchors) => [...anchors, ...newAnchors]);
      }
    };
    const documentObserver = new MutationObserver(documentObserverCallback);
    documentObserver.observe(document.body, {
      childList: true,
      subtree: true,
      attributes: true,
      attributeFilter: ["data-tooltip-id"]
    });
    return () => {
      documentObserver.disconnect();
    };
  }, [id, anchorSelect, activeAnchor]);
  useEffect3(() => {
    if (position) {
      handleTooltipPosition(position);
      return;
    }
    if (float) {
      if (lastFloatPosition.current) {
        handleTooltipPosition(lastFloatPosition.current);
      }
      return;
    }
    computeTooltipPosition({
      place,
      offset: offset2,
      elementReference: activeAnchor,
      tooltipReference: tooltipRef.current,
      tooltipArrowReference: tooltipArrowRef.current,
      strategy: positionStrategy,
      middlewares
    }).then((computedStylesData) => {
      if (!mounted.current) {
        return;
      }
      if (Object.keys(computedStylesData.tooltipStyles).length) {
        setInlineStyles(computedStylesData.tooltipStyles);
      }
      if (Object.keys(computedStylesData.tooltipArrowStyles).length) {
        setInlineArrowStyles(computedStylesData.tooltipArrowStyles);
      }
      setActualPlacement(computedStylesData.place);
    });
  }, [show, activeAnchor, content, place, offset2, positionStrategy, position]);
  useEffect3(() => {
    var _a;
    const anchorById = document.querySelector(`[id='${anchorId}']`);
    const anchors = [...anchorsBySelect, anchorById];
    if (!activeAnchor || !anchors.includes(activeAnchor)) {
      setActiveAnchor((_a = anchorsBySelect[0]) != null ? _a : anchorById);
    }
  }, [anchorId, anchorsBySelect, activeAnchor]);
  useEffect3(() => {
    return () => {
      if (tooltipShowDelayTimerRef.current) {
        clearTimeout(tooltipShowDelayTimerRef.current);
      }
      if (tooltipHideDelayTimerRef.current) {
        clearTimeout(tooltipHideDelayTimerRef.current);
      }
    };
  }, []);
  useEffect3(() => {
    let selector = anchorSelect;
    if (!selector && id) {
      selector = `[data-tooltip-id='${id}']`;
    }
    if (!selector) {
      return;
    }
    try {
      const anchors = Array.from(document.querySelectorAll(selector));
      setAnchorsBySelect(anchors);
    } catch (e) {
      setAnchorsBySelect([]);
    }
  }, [id, anchorSelect]);
  const canShow = content && show && Object.keys(inlineStyles).length > 0;
  return rendered ? /* @__PURE__ */ jsxs(
    WrapperElement,
    {
      id,
      role: "tooltip",
      className: classNames2(
        "react-tooltip",
        styles_module_default["tooltip"],
        styles_module_default[variant],
        className,
        `react-tooltip__place-${actualPlacement}`,
        {
          [styles_module_default["show"]]: canShow,
          [styles_module_default["fixed"]]: positionStrategy === "fixed",
          [styles_module_default["clickable"]]: clickable
        }
      ),
      style: { ...externalStyles, ...inlineStyles },
      ref: tooltipRef,
      children: [
        content,
        /* @__PURE__ */ jsx3(
          WrapperElement,
          {
            className: classNames2("react-tooltip-arrow", styles_module_default["arrow"], classNameArrow, {
              /**
               * changed from dash `no-arrow` to camelcase because of:
               * https://github.com/indooorsman/esbuild-css-modules-plugin/issues/42
               */
              [styles_module_default["noArrow"]]: noArrow
            }),
            style: inlineArrowStyles,
            ref: tooltipArrowRef
          }
        )
      ]
    }
  ) : null;
};
var Tooltip_default = Tooltip;

// src/components/TooltipContent/TooltipContent.tsx
import { jsx as jsx4 } from "react/jsx-runtime";
var TooltipContent = ({ content }) => {
  return /* @__PURE__ */ jsx4("span", { dangerouslySetInnerHTML: { __html: content } });
};
var TooltipContent_default = TooltipContent;

// src/components/TooltipController/TooltipController.tsx
import { jsx as jsx5 } from "react/jsx-runtime";
var TooltipController = ({
  id,
  anchorId,
  anchorSelect,
  content,
  html,
  render,
  className,
  classNameArrow,
  variant = "dark",
  place = "top",
  offset: offset2 = 10,
  wrapper = "div",
  children = null,
  events = ["hover"],
  openOnClick = false,
  positionStrategy = "absolute",
  middlewares,
  delayShow = 0,
  delayHide = 0,
  float = false,
  noArrow = false,
  clickable = false,
  closeOnEsc = false,
  style,
  position,
  isOpen,
  setIsOpen,
  afterShow,
  afterHide
}) => {
  const [tooltipContent, setTooltipContent] = useState3(content);
  const [tooltipHtml, setTooltipHtml] = useState3(html);
  const [tooltipPlace, setTooltipPlace] = useState3(place);
  const [tooltipVariant, setTooltipVariant] = useState3(variant);
  const [tooltipOffset, setTooltipOffset] = useState3(offset2);
  const [tooltipDelayShow, setTooltipDelayShow] = useState3(delayShow);
  const [tooltipDelayHide, setTooltipDelayHide] = useState3(delayHide);
  const [tooltipFloat, setTooltipFloat] = useState3(float);
  const [tooltipWrapper, setTooltipWrapper] = useState3(wrapper);
  const [tooltipEvents, setTooltipEvents] = useState3(events);
  const [tooltipPositionStrategy, setTooltipPositionStrategy] = useState3(positionStrategy);
  const [activeAnchor, setActiveAnchor] = useState3(null);
  const { anchorRefs, activeAnchor: providerActiveAnchor } = useTooltip(id);
  const getDataAttributesFromAnchorElement = (elementReference) => {
    const dataAttributes = elementReference == null ? void 0 : elementReference.getAttributeNames().reduce((acc, name) => {
      var _a;
      if (name.startsWith("data-tooltip-")) {
        const parsedAttribute = name.replace(/^data-tooltip-/, "");
        acc[parsedAttribute] = (_a = elementReference == null ? void 0 : elementReference.getAttribute(name)) != null ? _a : null;
      }
      return acc;
    }, {});
    return dataAttributes;
  };
  const applyAllDataAttributesFromAnchorElement = (dataAttributes) => {
    const handleDataAttributes = {
      place: (value) => {
        setTooltipPlace(value != null ? value : place);
      },
      content: (value) => {
        setTooltipContent(value != null ? value : content);
      },
      html: (value) => {
        setTooltipHtml(value != null ? value : html);
      },
      variant: (value) => {
        setTooltipVariant(value != null ? value : variant);
      },
      offset: (value) => {
        setTooltipOffset(value === null ? offset2 : Number(value));
      },
      wrapper: (value) => {
        setTooltipWrapper(value != null ? value : wrapper);
      },
      events: (value) => {
        const parsed = value == null ? void 0 : value.split(" ");
        setTooltipEvents(parsed != null ? parsed : events);
      },
      "position-strategy": (value) => {
        setTooltipPositionStrategy(value != null ? value : positionStrategy);
      },
      "delay-show": (value) => {
        setTooltipDelayShow(value === null ? delayShow : Number(value));
      },
      "delay-hide": (value) => {
        setTooltipDelayHide(value === null ? delayHide : Number(value));
      },
      float: (value) => {
        setTooltipFloat(value === null ? float : value === "true");
      }
    };
    Object.values(handleDataAttributes).forEach((handler) => handler(null));
    Object.entries(dataAttributes).forEach(([key, value]) => {
      var _a;
      (_a = handleDataAttributes[key]) == null ? void 0 : _a.call(handleDataAttributes, value);
    });
  };
  useEffect4(() => {
    setTooltipContent(content);
  }, [content]);
  useEffect4(() => {
    setTooltipHtml(html);
  }, [html]);
  useEffect4(() => {
    setTooltipPlace(place);
  }, [place]);
  useEffect4(() => {
    var _a;
    const elementRefs = new Set(anchorRefs);
    let selector = anchorSelect;
    if (!selector && id) {
      selector = `[data-tooltip-id='${id}']`;
    }
    if (selector) {
      try {
        const anchorsBySelect = document.querySelectorAll(selector);
        anchorsBySelect.forEach((anchor) => {
          elementRefs.add({ current: anchor });
        });
      } catch (e) {
        if (true) {
          console.warn(`[react-tooltip] "${anchorSelect}" is not a valid CSS selector`);
        }
      }
    }
    const anchorById = document.querySelector(`[id='${anchorId}']`);
    if (anchorById) {
      elementRefs.add({ current: anchorById });
    }
    if (!elementRefs.size) {
      return () => null;
    }
    const anchorElement = (_a = activeAnchor != null ? activeAnchor : anchorById) != null ? _a : providerActiveAnchor.current;
    const observerCallback = (mutationList) => {
      mutationList.forEach((mutation) => {
        var _a2;
        if (!anchorElement || mutation.type !== "attributes" || !((_a2 = mutation.attributeName) == null ? void 0 : _a2.startsWith("data-tooltip-"))) {
          return;
        }
        const dataAttributes = getDataAttributesFromAnchorElement(anchorElement);
        applyAllDataAttributesFromAnchorElement(dataAttributes);
      });
    };
    const observer = new MutationObserver(observerCallback);
    const observerConfig = { attributes: true, childList: false, subtree: false };
    if (anchorElement) {
      const dataAttributes = getDataAttributesFromAnchorElement(anchorElement);
      applyAllDataAttributesFromAnchorElement(dataAttributes);
      observer.observe(anchorElement, observerConfig);
    }
    return () => {
      observer.disconnect();
    };
  }, [anchorRefs, providerActiveAnchor, activeAnchor, anchorId, anchorSelect]);
  let renderedContent = children;
  if (render) {
    renderedContent = render({ content: tooltipContent != null ? tooltipContent : null, activeAnchor });
  } else if (tooltipContent) {
    renderedContent = tooltipContent;
  }
  if (tooltipHtml) {
    renderedContent = /* @__PURE__ */ jsx5(TooltipContent_default, { content: tooltipHtml });
  }
  const props = {
    id,
    anchorId,
    anchorSelect,
    className,
    classNameArrow,
    content: renderedContent,
    place: tooltipPlace,
    variant: tooltipVariant,
    offset: tooltipOffset,
    wrapper: tooltipWrapper,
    events: tooltipEvents,
    openOnClick,
    positionStrategy: tooltipPositionStrategy,
    middlewares,
    delayShow: tooltipDelayShow,
    delayHide: tooltipDelayHide,
    float: tooltipFloat,
    noArrow,
    clickable,
    closeOnEsc,
    style,
    position,
    isOpen,
    setIsOpen,
    afterShow,
    afterHide,
    activeAnchor,
    setActiveAnchor: (anchor) => setActiveAnchor(anchor)
  };
  return /* @__PURE__ */ jsx5(Tooltip_default, { ...props });
};
var TooltipController_default = TooltipController;
export {
  TooltipController_default as Tooltip,
  TooltipProvider_default as TooltipProvider,
  TooltipWrapper_default as TooltipWrapper
};
//# sourceMappingURL=react-tooltip.esm.js.map
